package com.ruoyi.framework.recovery.mapper;

import java.util.List;
import com.ruoyi.framework.recovery.domain.RecCity;

/**
 * 城市管理Mapper接口
 * 
 * @author jin
 * @date 2024-11-20
 */
public interface RecCityMapper 
{
    /**
     * 查询城市管理
     * 
     * @param id 城市管理主键
     * @return 城市管理
     */
    public RecCity selectRecCityById(Long id);

    /**
     * 查询城市管理列表
     * 
     * @param recCity 城市管理
     * @return 城市管理集合
     */
    public List<RecCity> selectRecCityList(RecCity recCity);

    /**
     * 新增城市管理
     * 
     * @param recCity 城市管理
     * @return 结果
     */
    public int insertRecCity(RecCity recCity);

    /**
     * 修改城市管理
     * 
     * @param recCity 城市管理
     * @return 结果
     */
    public int updateRecCity(RecCity recCity);

    /**
     * 删除城市管理
     * 
     * @param id 城市管理主键
     * @return 结果
     */
    public int deleteRecCityById(Long id);

    /**
     * 批量删除城市管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecCityByIds(Long[] ids);
}
