package com.ruoyi.framework.recovery.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.framework.recovery.domain.RecCity;
import com.ruoyi.framework.recovery.service.IRecCityService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 城市管理Controller
 * 
 * @author jin
 * @date 2024-11-20
 */
@RestController
@RequestMapping("/recovery/city")
public class RecCityController extends BaseController
{
    @Autowired
    private IRecCityService recCityService;

    /**
     * 查询城市管理列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:city:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecCity recCity)
    {
        startPage();
        List<RecCity> list = recCityService.selectRecCityList(recCity);
        return getDataTable(list);
    }

    /**
     * 导出城市管理列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:city:export')")
    @Log(title = "城市管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecCity recCity)
    {
        List<RecCity> list = recCityService.selectRecCityList(recCity);
        ExcelUtil<RecCity> util = new ExcelUtil<RecCity>(RecCity.class);
        util.exportExcel(response, list, "城市管理数据");
    }

    /**
     * 获取城市管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('recovery:city:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(recCityService.selectRecCityById(id));
    }

    /**
     * 新增城市管理
     */
    @PreAuthorize("@ss.hasPermi('recovery:city:add')")
    @Log(title = "城市管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecCity recCity)
    {
        return toAjax(recCityService.insertRecCity(recCity));
    }

    /**
     * 修改城市管理
     */
    @PreAuthorize("@ss.hasPermi('recovery:city:edit')")
    @Log(title = "城市管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecCity recCity)
    {
        return toAjax(recCityService.updateRecCity(recCity));
    }

    /**
     * 删除城市管理
     */
    @PreAuthorize("@ss.hasPermi('recovery:city:remove')")
    @Log(title = "城市管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(recCityService.deleteRecCityByIds(ids));
    }
}
